==> ukui-biometric-auth_3.22.0.0.orig.tar.gz: ukui-biometric-auth-3.22.0.0/bioauth/i18n_ts/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BioAuthWidget</name>
    <message>
        <location filename="../src/bioauthwidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>More</source>
        <translation type="vanished">更多</translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.ui" line="146"/>
        <location filename="../src/bioauthwidget.cpp" line="41"/>
        <source>Retry</source>
        <translation>重试</translation>
    </message>
    <message>
        <source>Too many unsuccessful attempts,please enter password.</source>
        <translation type="vanished">验证失败达最大次数，请使用密码解锁</translation>
    </message>
    <message>
        <source>Bioauth authentication failed, you still have %1 verification opportunities</source>
        <translation type="vanished">生物认证失败，您还有%1次尝试机会</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">密码</translation>
    </message>
    <message>
        <source>Current Device: </source>
        <translation type="vanished">当前设备：</translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="96"/>
        <location filename="../src/bioauthwidget.cpp" line="212"/>
        <source>%1 too many unsuccessful attempts,please enter password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="102"/>
        <source>%1 authentication failure,there are still %2 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="226"/>
        <source>Please use wechat to scan the code</source>
        <translation>请使用微信扫码</translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <location filename="../src/biodevices.cpp" line="64"/>
        <source>Unplugging of %1 device detected</source>
        <translation>检测到%1设备拔出</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="74"/>
        <source>%1 device insertion detected</source>
        <translation>检测到%1设备插入</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="83"/>
        <source>ukui-biometric-manager</source>
        <translation>生物特征管理工具</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="86"/>
        <source>biometric</source>
        <translation>生物特征</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="457"/>
        <source>FingerPrint</source>
        <translation>指纹</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="459"/>
        <source>FingerVein</source>
        <translation>指静脉</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="461"/>
        <source>Iris</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="463"/>
        <source>Face</source>
        <translation>人脸识别</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="465"/>
        <source>VoicePrint</source>
        <translation>声纹</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="467"/>
        <source>QRCode</source>
        <translation>二维码</translation>
    </message>
    <message>
        <source>Wechat</source>
        <translation type="vanished">微信</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <location filename="../src/biodeviceswidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Device types:</source>
        <translation type="vanished">设备类型：</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">返回</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">确定</translation>
    </message>
    <message>
        <source>FingerPrint</source>
        <translation type="vanished">指纹</translation>
    </message>
</context>
<context>
    <name>LoginOptionsWidget</name>
    <message>
        <location filename="../src/loginoptionswidget.cpp" line="59"/>
        <source>Login Options</source>
        <translation>登录选项</translation>
    </message>
    <message>
        <source>Wechat</source>
        <translation type="vanished">微信</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation type="vanished">生物识别</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>FingerPrint</source>
        <translation type="vanished">指纹</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="vanished">指静脉</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="vanished">虹膜</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="vanished">人脸</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="vanished">声纹</translation>
    </message>
</context>
</TS>

==> ukui-biometric-auth_4.0.0.0.orig.tar.gz: ukui-biometric-auth-4.0.0.0/bioauth/i18n_ts/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BioAuthWidget</name>
    <message>
        <location filename="../src/bioauthwidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>More</source>
        <translation type="vanished">更多</translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.ui" line="146"/>
        <location filename="../src/bioauthwidget.cpp" line="41"/>
        <source>Retry</source>
        <translation>重试</translation>
    </message>
    <message>
        <source>Too many unsuccessful attempts,please enter password.</source>
        <translation type="vanished">验证失败达最大次数，请使用密码解锁</translation>
    </message>
    <message>
        <source>Bioauth authentication failed, you still have %1 verification opportunities</source>
        <translation type="vanished">生物认证失败，您还有%1次尝试机会</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Current Device: </source>
        <translation type="vanished">当前设备：</translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="96"/>
        <location filename="../src/bioauthwidget.cpp" line="212"/>
        <source>%1 too many unsuccessful attempts,please enter password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="102"/>
        <source>%1 authentication failure,there are still %2 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="226"/>
        <source>Please use wechat to scan the code</source>
        <translation>请使用微信扫码</translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <location filename="../src/biodevices.cpp" line="64"/>
        <source>Unplugging of %1 device detected</source>
        <translation>检测到%1设备拔出</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="74"/>
        <source>%1 device insertion detected</source>
        <translation>检测到%1设备插入</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="83"/>
        <source>ukui-biometric-manager</source>
        <translation>生物特征管理工具</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="86"/>
        <source>biometric</source>
        <translation>生物特征</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="457"/>
        <source>FingerPrint</source>
        <translation>指纹</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="459"/>
        <source>FingerVein</source>
        <translation>指静脉</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="461"/>
        <source>Iris</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="463"/>
        <source>Face</source>
        <translation>人脸识别</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="465"/>
        <source>VoicePrint</source>
        <translation>声纹</translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="657"/>
        <source>ukey</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="659"/>
        <source>QRCode</source>
        <translation>二维码</translation>
    </message>
    <message>
        <source>Wechat</source>
        <translation type="vanished">微信</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <location filename="../src/biodeviceswidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Device types:</source>
        <translation type="vanished">设备类型：</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">返回</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">确定</translation>
    </message>
    <message>
        <source>FingerPrint</source>
        <translation type="vanished">指纹</translation>
    </message>
</context>
<context>
    <name>LoginOptionsWidget</name>
    <message>
        <location filename="../src/loginoptionswidget.cpp" line="59"/>
        <source>Login Options</source>
        <translation>登录选项</translation>
    </message>
    <message>
        <location filename="../src/loginoptionswidget.cpp" line="294"/>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Wechat</source>
        <translation type="vanished">微信</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation type="vanished">生物识别</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>FingerPrint</source>
        <translation type="vanished">指纹</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="vanished">指静脉</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="vanished">虹膜</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="vanished">人脸</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="vanished">声纹</translation>
    </message>
</context>
</TS>
